@@ -4,6 +4,8 @@ from .core import *
 __all__ = [
     'pt',
     'dbf2objs',
+    'str2objs',
+    'read_fields',
     'compare_fields',
     'split_multiline',
 ]
