@@ -1,8 +1,6 @@
 import heyy
 import dbfread
 
-pt = heyy.pathtool
-
 
 def dbf2objs(filename, encoding='gbk', ignore_case=True):
     dbf = dbfread.DBF(filename, encoding)
@@ -11,6 +9,19 @@ def dbf2objs(filename, encoding='gbk', ignore_case=True):
     return objs
 
 
+def str2objs(attrs, string, *, sep='\t', newline='\n'):
+    rows = string.split(newline)
+    if not isinstance(attrs, bool):
+        def head(): return attrs
+    elif attrs:
+        title, rows = rows[0].split(sep), rows[1:]
+        def head(): return title
+    else:
+        from itertools import cycle
+        def head(): return (f'{v}{i + 1}' for i, v in enumerate(cycle('a')))
+    return [heyy.json2obj(zip(head(), s.split(sep))) for s in rows]
+
+
 def read_fields(dbf_filename, encoding='gbk'):
     dbf = dbfread.DBF(dbf_filename, encoding)
     return dbf.field_names
